@@ -175,7 +175,7 @@ main(int argc, char *argv[])
         outmessage.msg_iov->iov_len = strlen(message) + 1;
 
 	memset(&inmessage, 0, sizeof(inmessage));
-        buffer_rcv = malloc(REALLY_BIG);
+        buffer_rcv = test_malloc(REALLY_BIG);
 
         iov_rcv.iov_base = buffer_rcv;
         iov_rcv.iov_len = REALLY_BIG;
@@ -205,5 +205,7 @@ main(int argc, char *argv[])
 
 	close(lstn_sk);
 	close(acpt_sk);
+
+	free(buffer_rcv);
 	return 0;
 }
