@@ -112,7 +112,7 @@ main(int argc, char *argv[])
 	acpt_sk = test_accept(lstn_sk, (struct sockaddr *)&svr_addr, &len);
 
 	memset(&inmessage, 0, sizeof(inmessage));
-        buffer_rcv = malloc(REALLY_BIG);
+        buffer_rcv = test_malloc(REALLY_BIG);
 
         iov_rcv.iov_base = buffer_rcv;
         iov_rcv.iov_len = REALLY_BIG;
@@ -212,5 +212,7 @@ main(int argc, char *argv[])
 	close(sk);
 	close(lstn_sk);
 	close(acpt_sk);
+
+	free(buffer_rcv);
 	return 0;
 }
