@@ -179,7 +179,7 @@ main(int argc, char *argv[])
 
         lstn_sk = test_socket(pf_class, SOCK_STREAM, IPPROTO_SCTP);
 
-	message_rcv = malloc(512);
+	message_rcv = test_malloc(512);
 
 	/*Binding the listen socket*/
         test_bind(lstn_sk, (struct sockaddr *) &lstn_addr, sizeof(lstn_addr));
@@ -233,9 +233,10 @@ main(int argc, char *argv[])
 	test_recv(acpt_sk, message_rcv, strlen(message) + 1, flag);
 	tst_resm(TPASS, "sctp_send() with no sinfo - SUCCESS");
 
-	close(sk1);
+	close(sk);
 	close(lstn_sk);
 	close(acpt_sk);
 
+	free(message_rcv);
 	return 0;
 }
